# kiirastuli

Purgatory (Finnish: kiirastuli) - purge like hell to stay out of trouble.

[License: MIT](https://git.sr.ht/~sthagen/kiirastuli/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)
[![downloads](https://img.shields.io/pypi/dm/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)
[![wheel](https://img.shields.io/pypi/wheel/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)
[![supported-versions](https://img.shields.io/pypi/pyversions/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)
[![supported-implementations](https://img.shields.io/pypi/implementation/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of kiirastuli](https://todo.sr.ht/~sthagen/kiirastuli).

## Primary Source repository

The primary source repository of [kiirastuli is at sourcehut](https://git.sr.ht/~sthagen/kiirastuli)
a collection of tools useful for software development.
